@@ -12,7 +12,9 @@ import xarray as xr
 try:
     import ujson as json
 except ImportError:
-    import json
+    # mypy struggles with conditional imports expressed as catching ImportError:
+    # https://github.com/python/mypy/issues/1153
+    import json  # type: ignore
 
 from .. import __version__, utils
 
@@ -46,7 +48,9 @@ class requires:  # pylint: disable=invalid-name
         return wrapped
 
 
-def generate_dims_coords(shape, var_name, dims=None, coords=None, default_dims=None):
+def generate_dims_coords(
+    shape, var_name, dims=None, coords=None, default_dims=None, skip_event_dims=None
+):
     """Generate default dimensions and coordinates for a variable.
 
     Parameters
@@ -66,6 +70,7 @@ def generate_dims_coords(shape, var_name, dims=None, coords=None, default_dims=N
         when manipulating Monte Carlo traces, the ``default_dims`` would be
         ``["chain" , "draw"]`` which ArviZ uses as its own names for dimensions
         of MCMC traces.
+    skip_event_dims : bool, default False
 
     Returns
     -------
@@ -78,26 +83,41 @@ def generate_dims_coords(shape, var_name, dims=None, coords=None, default_dims=N
         default_dims = []
     if dims is None:
         dims = []
-    if len([dim for dim in dims if dim not in default_dims]) > len(shape):
-        warnings.warn(
-            (
-                "In variable {var_name}, there are "
-                + "more dims ({dims_len}) given than exist ({shape_len}). "
-                + "Passed array should have shape ({defaults}*shape)"
-            ).format(
-                var_name=var_name,
-                dims_len=len(dims),
-                shape_len=len(shape),
-                defaults=",".join(default_dims) + ", " if default_dims is not None else "",
-            ),
-            UserWarning,
-        )
+    if skip_event_dims is None:
+        skip_event_dims = False
+
     if coords is None:
         coords = {}
 
     coords = deepcopy(coords)
     dims = deepcopy(dims)
 
+    ndims = len([dim for dim in dims if dim not in default_dims])
+    if ndims > len(shape):
+        if skip_event_dims:
+            dims = dims[: len(shape)]
+        else:
+            warnings.warn(
+                (
+                    "In variable {var_name}, there are "
+                    + "more dims ({dims_len}) given than exist ({shape_len}). "
+                    + "Passed array should have shape ({defaults}*shape)"
+                ).format(
+                    var_name=var_name,
+                    dims_len=len(dims),
+                    shape_len=len(shape),
+                    defaults=",".join(default_dims) + ", " if default_dims is not None else "",
+                ),
+                UserWarning,
+            )
+    if skip_event_dims:
+        # this is needed in case the reduction keeps the dimension with size 1
+        for i, (dim, dim_size) in enumerate(zip(dims, shape)):
+            print(f"{i}, dim: {dim}, {dim_size} =? {len(coords.get(dim, []))}")
+            if (dim in coords) and (dim_size != len(coords[dim])):
+                dims = dims[:i]
+                break
+
     for idx, dim_len in enumerate(shape):
         if (len(dims) < idx + 1) or (dims[idx] is None):
             dim_name = "{var_name}_dim_{idx}".format(var_name=var_name, idx=idx)
@@ -112,7 +132,7 @@ def generate_dims_coords(shape, var_name, dims=None, coords=None, default_dims=N
     return dims, coords
 
 
-def numpy_to_data_array(ary, *, var_name="data", coords=None, dims=None):
+def numpy_to_data_array(ary, *, var_name="data", coords=None, dims=None, skip_event_dims=None):
     """Convert a numpy array to an xarray.DataArray.
 
     The first two dimensions will be (chain, draw), and any remaining
@@ -134,6 +154,7 @@ def numpy_to_data_array(ary, *, var_name="data", coords=None, dims=None):
         is the name of the dimension, the values are the index values.
     dims : List(str)
         A list of coordinate names for the variable
+    skip_event_dims : bool
 
     Returns
     -------
@@ -154,7 +175,12 @@ def numpy_to_data_array(ary, *, var_name="data", coords=None, dims=None):
         )
 
     dims, coords = generate_dims_coords(
-        shape, var_name, dims=dims, coords=coords, default_dims=default_dims
+        shape,
+        var_name,
+        dims=dims,
+        coords=coords,
+        default_dims=default_dims,
+        skip_event_dims=skip_event_dims,
     )
 
     # reversed order for default dims: 'chain', 'draw'
@@ -173,7 +199,9 @@ def numpy_to_data_array(ary, *, var_name="data", coords=None, dims=None):
     return xr.DataArray(ary, coords=coords, dims=dims)
 
 
-def dict_to_dataset(data, *, attrs=None, library=None, coords=None, dims=None):
+def dict_to_dataset(
+    data, *, attrs=None, library=None, coords=None, dims=None, skip_event_dims=None
+):
     """Convert a dictionary of numpy arrays to an xarray.Dataset.
 
     Parameters
@@ -189,6 +217,11 @@ def dict_to_dataset(data, *, attrs=None, library=None, coords=None, dims=None):
     dims : dict[str] -> list[str]
         Dimensions of each variable. The keys are variable names, values are lists of
         coordinates.
+    skip_event_dims : bool
+        If True, cut extra dims whenever present to match the shape of the data.
+        Necessary for PPLs which have the same name in both observed data and log
+        likelihood groups, to account for their different shapes when observations are
+        multivariate.
 
     Returns
     -------
@@ -205,7 +238,7 @@ def dict_to_dataset(data, *, attrs=None, library=None, coords=None, dims=None):
     data_vars = {}
     for key, values in data.items():
         data_vars[key] = numpy_to_data_array(
-            values, var_name=key, coords=coords, dims=dims.get(key)
+            values, var_name=key, coords=coords, dims=dims.get(key), skip_event_dims=skip_event_dims
         )
     return xr.Dataset(data_vars=data_vars, attrs=make_attrs(attrs=attrs, library=library))
 
@@ -243,8 +276,23 @@ def make_attrs(attrs=None, library=None):
     return default_attrs
 
 
-def _extend_xr_method(func):
-    """Make wrapper to extend methods from xr.Dataset to InferenceData Class."""
+def _extend_xr_method(func, doc="", description="", examples="", see_also=""):
+    """Make wrapper to extend methods from xr.Dataset to InferenceData Class.
+
+    Parameters
+    ----------
+    func : callable
+        An xr.Dataset function
+    doc : str
+        docstring for the func
+    description : str
+        the description of the func to be added in docstring
+    examples : str
+        the examples of the func to be added in docstring
+    see_also : str, list
+        the similar methods of func to be included in See Also section of docstring
+
+    """
     # pydocstyle requires a non empty line
 
     @functools.wraps(func)
@@ -263,10 +311,11 @@ def _extend_xr_method(func):
 
         return None if _inplace else out
 
-    description = """
-    This method is extended from xarray.Dataset methods. For more info see :meth:`xarray:xarray.Dataset.{method_name}`
+    description_default = """{method_name} method is extended from xarray.Dataset methods.
+    
+    {description}For more info see :meth:`xarray:xarray.Dataset.{method_name}`
     """.format(
-        method_name=func.__name__  # pylint: disable=no-member
+        description=description, method_name=func.__name__  # pylint: disable=no-member
     )
     params = """
     Parameters
@@ -283,14 +332,20 @@ def _extend_xr_method(func):
         If ``True``, modify the InferenceData object inplace,
         otherwise, return the modified copy.
     """
-    see_also = """
+
+    if not isinstance(see_also, str):
+        see_also = "\n".join(see_also)
+    see_also_basic = """
     See Also
     --------
     xarray.Dataset.{method_name}
+    {custom_see_also}
     """.format(
-        method_name=func.__name__  # pylint: disable=no-member
+        method_name=func.__name__, custom_see_also=see_also  # pylint: disable=no-member
+    )
+    wrapped.__doc__ = (
+        description_default + params + examples + see_also_basic if doc is None else doc
     )
-    wrapped.__doc__ = description + params + see_also
 
     return wrapped
 
@@ -301,7 +356,7 @@ def _make_json_serializable(data: dict) -> dict:
     for key, value in data.items():
         try:
             json.dumps(value)
-        except TypeError:
+        except (TypeError, OverflowError):
             pass
         else:
             ret[key] = value
