@@ -4,10 +4,9 @@ import os
 import re
 from collections import defaultdict
 from glob import glob
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 import numpy as np
-import pandas as pd
 import xarray as xr
 
 from .. import utils
@@ -56,6 +55,7 @@ class CmdStanConverter:
         dims=None,
         disable_glob=False,
         save_warmup=None,
+        dtypes=None,
     ):
         self.posterior_ = check_glob(posterior, "posterior", disable_glob)
         self.posterior_predictive = check_glob(
@@ -75,37 +75,41 @@ class CmdStanConverter:
         self.dims = dims if dims is not None else {}
 
         self.posterior = None
-        self.sample_stats = None
         self.prior = None
-        self.sample_stats_prior = None
         self.attrs = None
         self.attrs_prior = None
 
         self.save_warmup = rcParams["data.save_warmup"] if save_warmup is None else save_warmup
 
+        if dtypes is None:
+            self.dtypes = {}
+        else:
+            self.dtypes = dtypes
         # populate posterior and sample_stats
         self._parse_posterior()
         self._parse_prior()
 
     @requires("posterior_")
     def _parse_posterior(self):
-        """Read csv paths to list of dataframes."""
+        """Read csv paths to list of ndarrays."""
         paths = self.posterior_
         if isinstance(paths, str):
             paths = [paths]
 
         chain_data = []
+        columns = None
         for path in paths:
-            chain_data.append(_read_output(path))
+            output_data = _read_output(path)
+            chain_data.append(output_data)
+            if columns is None:
+                columns = output_data
 
         self.posterior = (
             [item["sample"] for item in chain_data],
             [item["sample_warmup"] for item in chain_data],
         )
-        self.sample_stats = (
-            [item["sample_stats"] for item in chain_data],
-            [item["sample_stats_warmup"] for item in chain_data],
-        )
+        self.posterior_columns = columns["sample_columns"]
+        self.sample_stats_columns = columns["sample_stats_columns"]
 
         attrs = {}
         for item in chain_data:
@@ -117,23 +121,25 @@ class CmdStanConverter:
 
     @requires("prior_")
     def _parse_prior(self):
-        """Read csv paths to list of dataframes."""
+        """Read csv paths to list of ndarrays."""
         paths = self.prior_
         if isinstance(paths, str):
             paths = [paths]
 
         chain_data = []
+        columns = None
         for path in paths:
-            chain_data.append(_read_output(path))
+            output_data = _read_output(path)
+            chain_data.append(output_data)
+            if columns is None:
+                columns = output_data
 
         self.prior = (
             [item["sample"] for item in chain_data],
             [item["sample_warmup"] for item in chain_data],
         )
-        self.sample_stats_prior = (
-            [item["sample_stats"] for item in chain_data],
-            [item["sample_stats_warmup"] for item in chain_data],
-        )
+        self.prior_columns = columns["sample_columns"]
+        self.sample_stats_prior_columns = columns["sample_stats_columns"]
 
         attrs = {}
         for item in chain_data:
@@ -146,7 +152,7 @@ class CmdStanConverter:
     @requires("posterior")
     def posterior_to_xarray(self):
         """Extract posterior samples from output csv."""
-        columns = self.posterior[0][0].columns
+        columns = self.posterior_columns
 
         # filter posterior_predictive, predictions and log_likelihood
         posterior_predictive = self.posterior_predictive
@@ -190,40 +196,48 @@ class CmdStanConverter:
             ]
 
         invalid_cols = posterior_predictive + predictions + log_likelihood
-        valid_cols = [col for col in columns if col not in invalid_cols]
-        data = _unpack_dataframes([item[valid_cols] for item in self.posterior[0]])
-        data_warmup = _unpack_dataframes([item[valid_cols] for item in self.posterior[1]])
+        valid_cols = {col: idx for col, idx in columns.items() if col not in invalid_cols}
+        data = _unpack_ndarrays(self.posterior[0], valid_cols, self.dtypes)
+        data_warmup = _unpack_ndarrays(self.posterior[1], valid_cols, self.dtypes)
         return (
             dict_to_dataset(data, coords=self.coords, dims=self.dims, attrs=self.attrs),
             dict_to_dataset(data_warmup, coords=self.coords, dims=self.dims, attrs=self.attrs),
         )
 
     @requires("posterior")
-    @requires("sample_stats")
+    @requires("sample_stats_columns")
     def sample_stats_to_xarray(self):
         """Extract sample_stats from fit."""
-        dtypes = {"divergent__": bool, "n_leapfrog__": np.int64, "treedepth__": np.int64}
+        dtypes = {"diverging": bool, "n_steps": np.int64, "tree_depth": np.int64, **self.dtypes}
+        rename_dict = {
+            "divergent": "diverging",
+            "n_leapfrog": "n_steps",
+            "treedepth": "tree_depth",
+            "stepsize": "step_size",
+            "accept_stat": "acceptance_rate",
+        }
 
-        sampler_params, sampler_params_warmup = self.sample_stats
+        columns_new = {}
+        for key, idx in self.sample_stats_columns.items():
+            name = re.sub("__$", "", key)
+            name = rename_dict.get(name, name)
+            columns_new[name] = idx
 
-        for j, s_params in enumerate(sampler_params):
-            rename_dict = {}
-            for key in s_params:
-                key_, *end = key.split(".")
-                name = re.sub("__$", "", key_)
-                name = "diverging" if name == "divergent" else name
-                rename_dict[key] = ".".join((name, *end))
-                sampler_params[j][key] = s_params[key].astype(dtypes.get(key_))
-                sampler_params_warmup[j][key] = sampler_params_warmup[j][key].astype(
-                    dtypes.get(key_)
-                )
-            sampler_params[j] = sampler_params[j].rename(columns=rename_dict)
-            sampler_params_warmup[j] = sampler_params_warmup[j].rename(columns=rename_dict)
-        data = _unpack_dataframes(sampler_params)
-        data_warmup = _unpack_dataframes(sampler_params_warmup)
+        data = _unpack_ndarrays(self.posterior[0], columns_new, dtypes)
+        data_warmup = _unpack_ndarrays(self.posterior[1], columns_new, dtypes)
         return (
-            dict_to_dataset(data, coords=self.coords, dims=self.dims, attrs=self.attrs),
-            dict_to_dataset(data_warmup, coords=self.coords, dims=self.dims, attrs=self.attrs),
+            dict_to_dataset(
+                data,
+                coords=self.coords,
+                dims=self.dims,
+                attrs={item: key for key, item in rename_dict.items()},
+            ),
+            dict_to_dataset(
+                data_warmup,
+                coords=self.coords,
+                dims=self.dims,
+                attrs={item: key for key, item in rename_dict.items()},
+            ),
         )
 
     @requires("posterior")
@@ -232,8 +246,6 @@ class CmdStanConverter:
         """Convert posterior_predictive samples to xarray."""
         posterior_predictive = self.posterior_predictive
 
-        columns = self.posterior[0][0].columns
-
         if (
             isinstance(posterior_predictive, (tuple, list))
             and posterior_predictive[0].endswith(".csv")
@@ -242,34 +254,33 @@ class CmdStanConverter:
                 posterior_predictive = [posterior_predictive]
             chain_data = []
             chain_data_warmup = []
+            columns = None
             attrs = {}
             for path in posterior_predictive:
                 parsed_output = _read_output(path)
                 chain_data.append(parsed_output["sample"])
                 chain_data_warmup.append(parsed_output["sample_warmup"])
+                if columns is None:
+                    columns = parsed_output["sample_columns"]
 
                 for key, value in parsed_output["configuration_info"].items():
                     if key not in attrs:
                         attrs[key] = []
                     attrs[key].append(value)
 
-            data = _unpack_dataframes(chain_data)
-            data_warmup = _unpack_dataframes(chain_data_warmup)
+            data = _unpack_ndarrays(chain_data, columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(chain_data_warmup, columns, self.dtypes)
 
         else:
             if isinstance(posterior_predictive, str):
                 posterior_predictive = [posterior_predictive]
-            posterior_predictive_cols = [
-                col
-                for col in columns
+            columns = {
+                col: idx
+                for col, idx in self.posterior_columns.items()
                 if any(item == col.split(".")[0] for item in posterior_predictive)
-            ]
-            data = _unpack_dataframes(
-                [item[posterior_predictive_cols] for item in self.posterior[0]]
-            )
-            data_warmup = _unpack_dataframes(
-                [item[posterior_predictive_cols] for item in self.posterior[1]]
-            )
+            }
+            data = _unpack_ndarrays(self.posterior[0], columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(self.posterior[1], columns, self.dtypes)
 
             attrs = None
         return (
@@ -283,8 +294,6 @@ class CmdStanConverter:
         """Convert out of sample predictions samples to xarray."""
         predictions = self.predictions
 
-        columns = self.posterior[0][0].columns
-
         if (isinstance(predictions, (tuple, list)) and predictions[0].endswith(".csv")) or (
             isinstance(predictions, str) and predictions.endswith(".csv")
         ):
@@ -292,27 +301,32 @@ class CmdStanConverter:
                 predictions = [predictions]
             chain_data = []
             chain_data_warmup = []
+            columns = None
             attrs = {}
             for path in predictions:
                 parsed_output = _read_output(path)
                 chain_data.append(parsed_output["sample"])
                 chain_data_warmup.append(parsed_output["sample_warmup"])
+                if columns is None:
+                    columns = parsed_output["sample_columns"]
 
                 for key, value in parsed_output["configuration_info"].items():
                     if key not in attrs:
                         attrs[key] = []
                     attrs[key].append(value)
 
-            data = _unpack_dataframes(chain_data)
-            data_warmup = _unpack_dataframes(chain_data_warmup)
+            data = _unpack_ndarrays(chain_data, columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(chain_data_warmup, columns, self.dtypes)
         else:
             if isinstance(predictions, str):
                 predictions = [predictions]
-            predictions_cols = [
-                col for col in columns if any(item == col.split(".")[0] for item in predictions)
-            ]
-            data = _unpack_dataframes([item[predictions_cols] for item in self.posterior[0]])
-            data_warmup = _unpack_dataframes([item[predictions_cols] for item in self.posterior[0]])
+            columns = {
+                col: idx
+                for col, idx in self.posterior_columns.items()
+                if any(item == col.split(".")[0] for item in predictions)
+            }
+            data = _unpack_ndarrays(self.posterior[0], columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(self.posterior[1], columns, self.dtypes)
 
             attrs = None
         return (
@@ -320,13 +334,63 @@ class CmdStanConverter:
             dict_to_dataset(data_warmup, coords=self.coords, dims=self.dims, attrs=attrs),
         )
 
+    @requires("posterior")
+    @requires("log_likelihood")
+    def log_likelihood_to_xarray(self):
+        """Convert elementwise log_likelihood samples to xarray."""
+        log_likelihood = self.log_likelihood
+
+        if (isinstance(log_likelihood, (tuple, list)) and log_likelihood[0].endswith(".csv")) or (
+            isinstance(log_likelihood, str) and log_likelihood.endswith(".csv")
+        ):
+            if isinstance(log_likelihood, str):
+                log_likelihood = [log_likelihood]
+
+            chain_data = []
+            chain_data_warmup = []
+            columns = None
+            attrs = {}
+            for path in log_likelihood:
+                parsed_output = _read_output(path)
+                chain_data.append(parsed_output["sample"])
+                chain_data_warmup.append(parsed_output["sample_warmup"])
+
+                if columns is None:
+                    columns = parsed_output["sample_columns"]
+
+                for key, value in parsed_output["configuration_info"].items():
+                    if key not in attrs:
+                        attrs[key] = []
+                    attrs[key].append(value)
+            data = _unpack_ndarrays(chain_data, columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(chain_data_warmup, columns, self.dtypes)
+        else:
+            if isinstance(log_likelihood, str):
+                log_likelihood = [log_likelihood]
+            columns = {
+                col: idx
+                for col, idx in self.posterior_columns.items()
+                if any(item == col.split(".")[0] for item in log_likelihood)
+            }
+            data = _unpack_ndarrays(self.posterior[0], columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(self.posterior[1], columns, self.dtypes)
+            attrs = None
+        return (
+            dict_to_dataset(
+                data, coords=self.coords, dims=self.dims, attrs=attrs, skip_event_dims=True
+            ),
+            dict_to_dataset(
+                data_warmup, coords=self.coords, dims=self.dims, attrs=attrs, skip_event_dims=True
+            ),
+        )
+
     @requires("prior")
     def prior_to_xarray(self):
         """Convert prior samples to xarray."""
         # filter prior_predictive
         prior_predictive = self.prior_predictive
 
-        columns = self.prior[0][0].columns
+        columns = self.prior_columns
 
         if prior_predictive is None or (
             isinstance(prior_predictive, str) and prior_predictive.lower().endswith(".csv")
@@ -342,9 +406,9 @@ class CmdStanConverter:
             ]
 
         invalid_cols = prior_predictive
-        valid_cols = [col for col in columns if col not in invalid_cols]
-        data = _unpack_dataframes([item[valid_cols] for item in self.prior[0]])
-        data_warmup = _unpack_dataframes([item[valid_cols] for item in self.prior[1]])
+        valid_cols = {col: idx for col, idx in columns.items() if col not in invalid_cols}
+        data = _unpack_ndarrays(self.prior[0], valid_cols, self.dtypes)
+        data_warmup = _unpack_ndarrays(self.prior[1], valid_cols, self.dtypes)
         return (
             dict_to_dataset(data, coords=self.coords, dims=self.dims, attrs=self.attrs_prior),
             dict_to_dataset(
@@ -353,31 +417,38 @@ class CmdStanConverter:
         )
 
     @requires("prior")
-    @requires("sample_stats_prior")
+    @requires("sample_stats_prior_columns")
     def sample_stats_prior_to_xarray(self):
         """Extract sample_stats from fit."""
-        dtypes = {"divergent__": bool, "n_leapfrog__": np.int64, "treedepth__": np.int64}
+        dtypes = {"diverging": bool, "n_steps": np.int64, "tree_depth": np.int64, **self.dtypes}
+        rename_dict = {
+            "divergent": "diverging",
+            "n_leapfrog": "n_steps",
+            "treedepth": "tree_depth",
+            "stepsize": "step_size",
+            "accept_stat": "acceptance_rate",
+        }
 
-        sampler_params, sampler_params_warmup = self.sample_stats_prior
-        for j, s_params in enumerate(sampler_params):
-            rename_dict = {}
-            for key in s_params:
-                key_, *end = key.split(".")
-                name = re.sub("__$", "", key_)
-                name = "diverging" if name == "divergent" else name
-                rename_dict[key] = ".".join((name, *end))
-                sampler_params[j][key] = s_params[key].astype(dtypes.get(key_))
-                sampler_params_warmup[j][key] = sampler_params_warmup[j][key].astype(
-                    dtypes.get(key_)
-                )
-            sampler_params[j] = sampler_params[j].rename(columns=rename_dict)
-            sampler_params_warmup[j] = sampler_params_warmup[j].rename(columns=rename_dict)
-        data = _unpack_dataframes(sampler_params)
-        data_warmup = _unpack_dataframes(sampler_params_warmup)
+        columns_new = {}
+        for key, idx in self.sample_stats_prior_columns.items():
+            name = re.sub("__$", "", key)
+            name = rename_dict.get(name, name)
+            columns_new[name] = idx
+
+        data = _unpack_ndarrays(self.posterior[0], columns_new, dtypes)
+        data_warmup = _unpack_ndarrays(self.posterior[1], columns_new, dtypes)
         return (
-            dict_to_dataset(data, coords=self.coords, dims=self.dims, attrs=self.attrs_prior),
             dict_to_dataset(
-                data_warmup, coords=self.coords, dims=self.dims, attrs=self.attrs_prior
+                data,
+                coords=self.coords,
+                dims=self.dims,
+                attrs={item: key for key, item in rename_dict.items()},
+            ),
+            dict_to_dataset(
+                data_warmup,
+                coords=self.coords,
+                dims=self.dims,
+                attrs={item: key for key, item in rename_dict.items()},
             ),
         )
 
@@ -387,11 +458,6 @@ class CmdStanConverter:
         """Convert prior_predictive samples to xarray."""
         prior_predictive = self.prior_predictive
 
-        if self.prior[0][0].empty:
-            columns = self.prior[0][0].columns
-        else:
-            columns = self.prior[1][0].columns
-
         if (
             isinstance(prior_predictive, (tuple, list)) and prior_predictive[0].endswith(".csv")
         ) or (isinstance(prior_predictive, str) and prior_predictive.endswith(".csv")):
@@ -399,29 +465,30 @@ class CmdStanConverter:
                 prior_predictive = [prior_predictive]
             chain_data = []
             chain_data_warmup = []
+            columns = None
             attrs = {}
             for path in prior_predictive:
                 parsed_output = _read_output(path)
                 chain_data.append(parsed_output["sample"])
                 chain_data_warmup.append(parsed_output["sample_warmup"])
+                if columns is None:
+                    columns = parsed_output["sample_columns"]
                 for key, value in parsed_output["configuration_info"].items():
                     if key not in attrs:
                         attrs[key] = []
                     attrs[key].append(value)
-            data = _unpack_dataframes(chain_data)
-            data_warmup = _unpack_dataframes(chain_data_warmup)
+            data = _unpack_ndarrays(chain_data, columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(chain_data_warmup, columns, self.dtypes)
         else:
             if isinstance(prior_predictive, str):
                 prior_predictive = [prior_predictive]
-            prior_predictive_cols = [
-                col
-                for col in columns
+            columns = {
+                col: idx
+                for col, idx in self.prior_columns.items()
                 if any(item == col.split(".")[0] for item in prior_predictive)
-            ]
-            data = _unpack_dataframes([item[prior_predictive_cols] for item in self.prior[0]])
-            data_warmup = _unpack_dataframes(
-                [item[prior_predictive_cols] for item in self.prior[1]]
-            )
+            }
+            data = _unpack_ndarrays(self.prior[0], columns, self.dtypes)
+            data_warmup = _unpack_ndarrays(self.prior[1], columns, self.dtypes)
             attrs = None
         return (
             dict_to_dataset(data, coords=self.coords, dims=self.dims, attrs=attrs),
@@ -485,53 +552,6 @@ class CmdStanConverter:
             predictions_constant_data[key] = xr.DataArray(vals, dims=val_dims, coords=coords)
         return xr.Dataset(data_vars=predictions_constant_data)
 
-    @requires("posterior")
-    @requires("log_likelihood")
-    def log_likelihood_to_xarray(self):
-        """Convert elementwise log_likelihood samples to xarray."""
-        log_likelihood = self.log_likelihood
-
-        columns = self.posterior[0][0].columns
-
-        if (isinstance(log_likelihood, (tuple, list)) and log_likelihood[0].endswith(".csv")) or (
-            isinstance(log_likelihood, str) and log_likelihood.endswith(".csv")
-        ):
-            if isinstance(log_likelihood, str):
-                log_likelihood = [log_likelihood]
-
-            chain_data = []
-            chain_data_warmup = []
-            attrs = {}
-            for path in log_likelihood:
-                parsed_output = _read_output(path)
-                chain_data.append(parsed_output["sample"])
-                chain_data_warmup.append(parsed_output["sample_warmup"])
-                for key, value in parsed_output["configuration_info"].items():
-                    if key not in attrs:
-                        attrs[key] = []
-                    attrs[key].append(value)
-            data = _unpack_dataframes(chain_data)
-            data_warmup = _unpack_dataframes(chain_data_warmup)
-        else:
-            if isinstance(log_likelihood, str):
-                log_likelihood = [log_likelihood]
-            log_likelihood_cols = [
-                col for col in columns if any(item == col.split(".")[0] for item in log_likelihood)
-            ]
-            data = _unpack_dataframes([item[log_likelihood_cols] for item in self.posterior[0]])
-            data_warmup = _unpack_dataframes(
-                [item[log_likelihood_cols] for item in self.posterior[1]]
-            )
-            attrs = None
-        return (
-            dict_to_dataset(
-                data, coords=self.coords, dims=self.dims, attrs=attrs, skip_event_dims=True
-            ),
-            dict_to_dataset(
-                data_warmup, coords=self.coords, dims=self.dims, attrs=attrs, skip_event_dims=True
-            ),
-        )
-
     def to_inference_data(self):
         """Convert all available data to an InferenceData object.
 
@@ -576,7 +596,7 @@ def _process_configuration(comments):
             results["step_size"] = float(val.strip())
         elif "inverse mass matrix" in comment:
             comment = re.sub(r"^\s*#\s*", "", next(comments_gen)).strip()
-            results["inverse_mass_matrix"] = np.array(comment.split(","), dtype=float)
+            results["inverse_mass_matrix"] = [float(item) for item in comment.split(",")]
         elif ("seconds" in comment) and any(
             item in comment for item in ("(Warm-up)", "(Sampling)", "(Total)")
         ):
@@ -616,25 +636,33 @@ def _process_configuration(comments):
                 key = match_empty.group(1)
                 results[key] = None
 
-    results = {key: results[key] for key in sorted(results)}
+    results = {key: str(results[key]) for key in sorted(results)}
     return results
 
 
 def _read_output_file(path):
+    """Read Stan csv file to ndarray."""
     comments = []
-
-    # read comments
+    data = []
+    columns = None
     with open(path, "rb") as f_obj:
+        # read header
         for line in f_obj:
             if line.startswith(b"#"):
-                comments.append(line.decode("utf-8").strip())
+                comments.append(line.strip().decode("utf-8"))
+                continue
+            columns = {key: idx for idx, key in enumerate(line.strip().decode("utf-8").split(","))}
+            break
+        # read data
+        for line in f_obj:
+            line = line.strip()
+            if line.startswith(b"#"):
+                comments.append(line.decode("utf-8"))
+                continue
+            if line:
+                data.append(np.array(line.split(b","), dtype=np.float64))
 
-    with open(path, "rb") as f_obj:
-        data = pd.read_csv(
-            f_obj, comment="#", float_precision=rcParams["data.pandas_float_precision"]
-        )
-
-    return data, comments
+    return columns, np.array(data, dtype=np.float64), comments
 
 
 def _read_output(path):
@@ -649,31 +677,29 @@ def _read_output(path):
     Dict[str, Any]
     """
     # Read data
-    data, comments = _read_output_file(path)
+    columns, data, comments = _read_output_file(path)
 
     pconf = _process_configuration(comments)
 
     # split dataframe to warmup and draws
-    saved_warmup = pconf.get("save_warmup", 0) * pconf.get("num_warmup", 0) // pconf.get("thin", 1)
+    saved_warmup = (
+        int(pconf.get("save_warmup", 0))
+        * int(pconf.get("num_warmup", 0))
+        // int(pconf.get("thin", 1))
+    )
 
-    data_warmup = data.iloc[:saved_warmup, :]
-    data = data.iloc[saved_warmup:, :]
+    data_warmup = data[:saved_warmup]
+    data = data[saved_warmup:]
 
     # Split data to sample_stats and sample
-    sample_stats_columns = [col for col in data.columns if col.endswith("__")]
-    sample_columns = [col for col in data.columns if col not in sample_stats_columns]
-
-    sample_stats = data.loc[:, sample_stats_columns]
-    sample_data = data.loc[:, sample_columns]
-
-    sample_stats_warmup = data_warmup.loc[:, sample_stats_columns]
-    sample_data_warmup = data_warmup.loc[:, sample_columns]
+    sample_stats_columns = {col: idx for col, idx in columns.items() if col.endswith("__")}
+    sample_columns = {col: idx for col, idx in columns.items() if col not in sample_stats_columns}
 
     return {
-        "sample": sample_data,
-        "sample_stats": sample_stats,
-        "sample_warmup": sample_data_warmup,
-        "sample_stats_warmup": sample_stats_warmup,
+        "sample": data,
+        "sample_warmup": data_warmup,
+        "sample_columns": sample_columns,
+        "sample_stats_columns": sample_stats_columns,
         "configuration_info": pconf,
     }
 
@@ -714,7 +740,7 @@ def _process_data_var(string):
 
 
 def _read_data(path):
-    """Read Rdump output and transform to Python dictionary.
+    """Read Rdump output to dictionary.
 
     Parameters
     ----------
@@ -741,12 +767,14 @@ def _read_data(path):
     return data
 
 
-def _unpack_dataframes(dfs):
-    """Transform a list of pandas.DataFrames to dictionary containing ndarrays.
+def _unpack_ndarrays(arrays, columns, dtypes=None):
+    """Transform a list of ndarrays to dictionary containing ndarrays.
 
     Parameters
     ----------
-    dfs : List[pandas.DataFrame]
+    arrays : List[np.ndarray]
+    columns: Dict[str, int]
+    dtypes: Dict[str, Any]
 
     Returns
     -------
@@ -754,28 +782,28 @@ def _unpack_dataframes(dfs):
         key, values pairs. Values are formatted to shape = (nchain, ndraws, *shape)
     """
     col_groups = defaultdict(list)
-    columns = dfs[0].columns
-    for col in columns:
+    for col, col_idx in columns.items():
         key, *loc = col.split(".")
         loc = tuple(int(i) - 1 for i in loc)
-        col_groups[key].append((col, loc))
+        col_groups[key].append((col_idx, loc))
 
-    chains = len(dfs)
-    draws = len(dfs[0])
+    chains = len(arrays)
+    draws = len(arrays[0])
     sample = {}
-    for key, cols_locs in col_groups.items():
-        ndim = np.array([loc for _, loc in cols_locs]).max(0) + 1
-        dtype = dfs[0][cols_locs[0][0]].dtype
-        sample[key] = utils.full((chains, draws, *ndim), 0, dtype=dtype)
-        for col, loc in cols_locs:
-            for chain_id, df in enumerate(dfs):
-                draw = df[col].values
-                if loc == ():
-                    sample[key][chain_id, :] = draw
-                else:
-                    axis1_all = range(sample[key].shape[1])
-                    slicer = (chain_id, axis1_all, *loc)
-                    sample[key][slicer] = draw
+    if draws:
+        for key, cols_locs in col_groups.items():
+            ndim = np.array([loc for _, loc in cols_locs]).max(0) + 1
+            dtype = dtypes.get(key, np.float64)
+            sample[key] = utils.full((chains, draws, *ndim), 0, dtype=dtype)
+            for col, loc in cols_locs:
+                for chain_id, arr in enumerate(arrays):
+                    draw = arr[:, col]
+                    if loc == ():
+                        sample[key][chain_id, :] = draw
+                    else:
+                        axis1_all = range(sample[key].shape[1])
+                        slicer = (chain_id, axis1_all, *loc)
+                        sample[key][slicer] = draw
     return sample
 
 
@@ -797,6 +825,7 @@ def from_cmdstan(
     dims: Optional[DimSpec] = None,
     disable_glob: Optional[bool] = False,
     save_warmup: Optional[bool] = None,
+    dtypes: Optional[Dict] = None,
 ) -> InferenceData:
     """Convert CmdStan data into an InferenceData object.
 
@@ -844,6 +873,8 @@ def from_cmdstan(
     save_warmup : bool
         Save warmup iterations into InferenceData object, if found in the input files.
         If not defined, use default defined by the rcParams.
+    dtypes : dict
+        A dictionary containing dtype information (int, float) for parameters.
 
     Returns
     -------
@@ -866,4 +897,5 @@ def from_cmdstan(
         dims=dims,
         disable_glob=disable_glob,
         save_warmup=save_warmup,
+        dtypes=dtypes,
     ).to_inference_data()
