@@ -9,7 +9,7 @@ import xarray
 from arviz.data.inference_data import InferenceData
 
 from ..rcparams import rcParams
-from .base import dict_to_dataset, requires
+from .base import dict_to_dataset
 
 
 class PyJAGSConverter:
@@ -18,16 +18,20 @@ class PyJAGSConverter:
     def __init__(
         self,
         *,
-        posterior: tp.Optional[tp.Dict[str, np.ndarray]] = None,
+        posterior: tp.Optional[tp.Mapping[str, np.ndarray]] = None,
         prior: tp.Optional[tp.Mapping[str, np.ndarray]] = None,
-        log_likelihood: tp.Optional[tp.Dict[str, str]] = None,
+        log_likelihood: tp.Optional[
+            tp.Union[str, tp.List[str], tp.Tuple[str, ...], tp.Mapping[str, str]]
+        ] = None,
         coords=None,
         dims=None,
-        save_warmup: bool = None,
-        warmup_iterations: int = 0
-    ):
+        save_warmup: tp.Optional[bool] = None,
+        warmup_iterations: int = 0,
+    ) -> None:
+        self.posterior: tp.Optional[tp.Mapping[str, np.ndarray]]
+        self.log_likelihood: tp.Optional[tp.Dict[str, np.ndarray]]
         if log_likelihood is not None and posterior is not None:
-            self.posterior = posterior.copy()  # create a shallow copy of the dictionary
+            posterior_copy = dict(posterior)  # create a shallow copy of the dictionary
 
             if isinstance(log_likelihood, str):
                 log_likelihood = [log_likelihood]
@@ -35,9 +39,10 @@ class PyJAGSConverter:
                 log_likelihood = {name: name for name in log_likelihood}
 
             self.log_likelihood = {
-                obs_var_name: self.posterior.pop(log_like_name)
+                obs_var_name: posterior_copy.pop(log_like_name)
                 for obs_var_name, log_like_name in log_likelihood.items()
             }
+            self.posterior = posterior_copy
         else:
             self.posterior = posterior
             self.log_likelihood = None
@@ -70,19 +75,25 @@ class PyJAGSConverter:
             ),
         )
 
-    @requires("posterior")
-    def posterior_to_xarray(self) -> tp.Tuple[xarray.Dataset, xarray.Dataset]:
+    def posterior_to_xarray(self) -> tp.Optional[tp.Tuple[xarray.Dataset, xarray.Dataset]]:
         """Extract posterior samples from fit."""
+        if self.posterior is None:
+            return None
+
         return self._pyjags_samples_to_xarray(self.posterior)
 
-    @requires("prior")
-    def prior_to_xarray(self) -> tp.Tuple[xarray.Dataset, xarray.Dataset]:
+    def prior_to_xarray(self) -> tp.Optional[tp.Tuple[xarray.Dataset, xarray.Dataset]]:
         """Extract posterior samples from fit."""
+        if self.prior is None:
+            return None
+
         return self._pyjags_samples_to_xarray(self.prior)
 
-    @requires("log_likelihood")
-    def log_likelihood_to_xarray(self) -> tp.Tuple[xarray.Dataset, xarray.Dataset]:
+    def log_likelihood_to_xarray(self) -> tp.Optional[tp.Tuple[xarray.Dataset, xarray.Dataset]]:
         """Extract log likelihood samples from fit."""
+        if self.log_likelihood is None:
+            return None
+
         return self._pyjags_samples_to_xarray(self.log_likelihood)
 
     def to_inference_data(self):
@@ -125,7 +136,7 @@ def get_draws(
     -------
     A tuple of two samples dictionaries in ArviZ format
     """
-    data_warmup = OrderedDict()
+    data_warmup: tp.Mapping[str, np.ndarray] = OrderedDict()
 
     if variables is None:
         variables = list(pyjags_samples.keys())
@@ -302,7 +313,7 @@ def _convert_arviz_dict_to_pyjags_dict(
 def from_pyjags(
     posterior: tp.Optional[tp.Mapping[str, np.ndarray]] = None,
     prior: tp.Optional[tp.Mapping[str, np.ndarray]] = None,
-    log_likelihood: tp.Optional[tp.Dict[str, str]] = None,
+    log_likelihood: tp.Optional[tp.Mapping[str, str]] = None,
     coords=None,
     dims=None,
     save_warmup=None,
@@ -314,7 +325,7 @@ def from_pyjags(
     Takes a python dictionary of samples that has been generated by the sample
     method of a model instance and returns an Arviz inference data object.
     For a usage example read the
-    :ref:`Cookbook section on from_pyjags <cookbook>`
+    :ref:`Creating InferenceData section on from_pyjags <creating_InferenceData>`
 
     Parameters
     ----------
