@@ -34,7 +34,7 @@ def plot_loo_pit(
     y,
     color,
     textsize,
-    credible_interval,
+    hdi_prob,
     plot_kwargs,
     backend_kwargs,
     show,
@@ -96,9 +96,7 @@ def plot_loo_pit(
             fill_kwargs.setdefault(
                 "step", "mid" if plot_kwargs["drawstyle"] == "steps-mid" else None
             )
-            fill_kwargs.setdefault(
-                "legend_label", "{:.3g}% credible interval".format(credible_interval)
-            )
+            fill_kwargs.setdefault("legend_label", "{:.3g}% credible interval".format(hdi_prob))
     elif use_hdi:
         if hdi_kwargs is None:
             hdi_kwargs = {}
