@@ -124,14 +124,12 @@ def plot_ppc(
             plot_kwargs = {"color": color, "alpha": alpha, "linewidth": 0.5 * linewidth}
             if dtype == "i":
                 plot_kwargs["drawstyle"] = "steps-pre"
-            ax_i.plot(
-                [], color=color, label="{} predictive {}".format(group.capitalize(), pp_var_name)
-            )
+            ax_i.plot([], color=color, label="{} predictive".format(group.capitalize()))
             if observed:
                 if dtype == "f":
                     plot_kde(
                         obs_vals,
-                        label="Observed {}".format(var_name),
+                        label="Observed",
                         plot_kwargs={"color": "k", "linewidth": linewidth, "zorder": 3},
                         fill_kwargs={"alpha": 0},
                         ax=ax_i,
@@ -144,7 +142,7 @@ def plot_ppc(
                     ax_i.plot(
                         bin_edges,
                         hist,
-                        label="Observed {}".format(var_name),
+                        label="Observed",
                         color="k",
                         linewidth=linewidth,
                         zorder=3,
@@ -179,7 +177,7 @@ def plot_ppc(
                         ax_i.plot(x_s, y_s, **plot_kwargs)
 
             if mean:
-                label = "{} predictive mean {}".format(group.capitalize(), pp_var_name)
+                label = "{} predictive mean".format(group.capitalize())
                 if dtype == "f":
                     rep = len(pp_densities)
                     len_density = len(pp_densities[0])
@@ -224,7 +222,7 @@ def plot_ppc(
                     *_empirical_cdf(obs_vals),
                     color="k",
                     linewidth=linewidth,
-                    label="Observed {}".format(var_name),
+                    label="Observed",
                     drawstyle=drawstyle,
                     zorder=3
                 )
@@ -253,7 +251,7 @@ def plot_ppc(
                     drawstyle=drawstyle,
                     linewidth=linewidth
                 )
-            ax_i.plot([], color=color, label="Posterior predictive {}".format(pp_var_name))
+            ax_i.plot([], color=color, label="Posterior predictive")
             if mean:
                 ax_i.plot(
                     *_empirical_cdf(pp_vals.flatten()),
@@ -261,7 +259,7 @@ def plot_ppc(
                     linestyle="--",
                     linewidth=linewidth * 1.5,
                     drawstyle=drawstyle,
-                    label="Posterior predictive mean {}".format(pp_var_name)
+                    label="Posterior predictive mean"
                 )
             ax_i.set_yticks([0, 0.5, 1])
 
@@ -276,7 +274,7 @@ def plot_ppc(
                             "linewidth": linewidth * 1.5,
                             "zorder": 3,
                         },
-                        label="Posterior predictive mean {}".format(pp_var_name),
+                        label="Posterior predictive mean",
                         ax=ax_i,
                         legend=legend,
                     )
@@ -290,7 +288,7 @@ def plot_ppc(
                         hist,
                         color=color,
                         linewidth=linewidth * 1.5,
-                        label="Posterior predictive mean {}".format(pp_var_name),
+                        label="Posterior predictive mean",
                         zorder=3,
                         linestyle="--",
                         drawstyle="steps-pre",
@@ -316,7 +314,7 @@ def plot_ppc(
                     color="k",
                     markersize=markersize,
                     alpha=alpha,
-                    label="Observed {}".format(var_name),
+                    label="Observed",
                     zorder=4,
                 )
 
@@ -340,9 +338,7 @@ def plot_ppc(
                         vals, yvals, "o", zorder=2, color=color, markersize=markersize, alpha=alpha
                     )
 
-            ax_i.plot(
-                [], color=color, marker="o", label="Posterior predictive {}".format(pp_var_name)
-            )
+            ax_i.plot([], color=color, marker="o", label="Posterior predictive")
 
             ax_i.set_yticks([])
 
