@@ -16,7 +16,9 @@ def plot_ppc(
     kind="kde",
     alpha=None,
     mean=True,
+    observed=True,
     color="C0",
+    grid=None,
     figsize=None,
     textsize=None,
     data_pairs=None,
@@ -51,8 +53,13 @@ def plot_ppc(
         Defaults to 0.2 for kind = kde and cumulative, for scatter defaults to 0.7
     mean: bool
         Whether or not to plot the mean posterior/prior predictive distribution. Defaults to True
+    observed: bool, default True
+        Whether or not to plot the observed data.
     color: str
         Valid matplotlib color. Defaults to C0
+    grid : tuple
+        Number of rows and columns. Defaults to None, the rows and columns are
+        automatically inferred.
     figsize: tuple
         Figure size. If None it will be defined automatically.
     textsize: float
@@ -153,12 +160,19 @@ def plot_ppc(
         >>> az.plot_ppc(data, kind='cumulative')
 
     Use the coords and flatten parameters to plot selected variable dimensions
-    across multiple plots.
+    across multiple plots. We will now modify the dimension `obs_id` to contain
+    indicate the name of the county where the measure was taken. The change has to
+    be done on both ``posterior_predictive`` and ``observed_data`` groups, which is
+    why we will use :meth:`~arviz.InferenceData.map` to apply the same function to
+    both groups. Afterwards, we will select the counties to be plotted with the
+    ``coords`` arg.
 
     .. plot::
         :context: close-figs
 
-        >>> az.plot_ppc(data, coords={'observed_county': ['ANOKA', 'BELTRAMI']}, flatten=[])
+        >>> obs_county = data.posterior["County"][data.constant_data["county_idx"]]
+        >>> data = data.assign_coords(obs_id=obs_county, groups="observed_vars")
+        >>> az.plot_ppc(data, coords={'obs_id': ['ANOKA', 'BELTRAMI']}, flatten=[])
 
     Plot the overlay using a stacked scatter plot that is particularly useful
     when the sample sizes are small.
@@ -167,7 +181,7 @@ def plot_ppc(
         :context: close-figs
 
         >>> az.plot_ppc(data, kind='scatter', flatten=[],
-        >>>             coords={'observed_county': ['AITKIN', 'BELTRAMI']})
+        >>>             coords={'obs_id': ['AITKIN', 'BELTRAMI']})
 
     Plot random posterior predictive sub-samples.
 
@@ -198,7 +212,7 @@ def plot_ppc(
         if animated:
             raise TypeError("Animation option is only supported with matplotlib backend.")
 
-    observed = data.observed_data
+    observed_data = data.observed_data
 
     if group == "posterior":
         predictive_dataset = data.posterior_predictive
@@ -206,8 +220,8 @@ def plot_ppc(
         predictive_dataset = data.prior_predictive
 
     if var_names is None:
-        var_names = list(observed.data_vars)
-    var_names = _var_names(var_names, observed, filter_vars)
+        var_names = list(observed_data.data_vars)
+    var_names = _var_names(var_names, observed_data, filter_vars)
     pp_var_names = [data_pairs.get(var, var) for var in var_names]
     pp_var_names = _var_names(pp_var_names, predictive_dataset, filter_vars)
 
@@ -216,7 +230,7 @@ def plot_ppc(
     elif flatten_pp is None:
         flatten_pp = flatten
     if flatten is None:
-        flatten = list(observed.dims.keys())
+        flatten = list(observed_data.dims.keys())
 
     if coords is None:
         coords = {}
@@ -244,12 +258,15 @@ def plot_ppc(
     pp_sample_ix = np.random.choice(total_pp_samples, size=num_pp_samples, replace=False)
 
     for key in coords.keys():
-        coords[key] = np.where(np.in1d(observed[key], coords[key]))[0]
+        coords[key] = np.where(np.in1d(observed_data[key], coords[key]))[0]
 
     obs_plotters = filter_plotters_list(
         list(
             xarray_var_iter(
-                observed.isel(coords), skip_dims=set(flatten), var_names=var_names, combined=True
+                observed_data.isel(coords),
+                skip_dims=set(flatten),
+                var_names=var_names,
+                combined=True,
             )
         ),
         "plot_ppc",
@@ -267,7 +284,7 @@ def plot_ppc(
             ),
         )
     ]
-    rows, cols = default_grid(length_plotters)
+    rows, cols = default_grid(length_plotters, grid=grid)
 
     ppcplot_kwargs = dict(
         ax=ax,
@@ -286,6 +303,7 @@ def plot_ppc(
         jitter=jitter,
         textsize=textsize,
         mean=mean,
+        observed=observed,
         total_pp_samples=total_pp_samples,
         legend=legend,
         group=group,
