@@ -67,7 +67,7 @@ def plot_trace(
     figsize: tuple of (float, float), optional
         If None, size is (12, variables * 2)
     rug: bool, optional
-        If True adds a rugplot. Defaults to False. Ignored for 2D KDE.
+        If True adds a rugplot of samples. Defaults to False. Ignored for 2D KDE.
         Only affects continuous variables.
     lines: list of tuple of (str, dict, array_like), optional
         List of (var_name, {'coord': selection}, [line, positions]) to be overplotted as
@@ -92,6 +92,10 @@ def plot_trace(
         Extra keyword arguments passed to `arviz.plot_dist`. Only affects continuous variables.
     trace_kwargs: dict, optional
         Extra keyword arguments passed to `plt.plot`
+    rank_kwargs : dict, optional
+        Extra keyword arguments passed to `arviz.plot_rank`
+    axes: axes, optional
+        Matplotlib axes or bokeh figures.
     backend: {"matplotlib", "bokeh"}, optional
         Select plotting backend.
     backend_config: dict, optional
@@ -172,19 +176,21 @@ def plot_trace(
     else:
         divergence_data = False
 
-    data = get_coords(convert_to_dataset(data, group="posterior"), coords)
+    coords_data = get_coords(convert_to_dataset(data, group="posterior"), coords)
 
     if transform is not None:
-        data = transform(data)
+        coords_data = transform(coords_data)
 
-    var_names = _var_names(var_names, data, filter_vars)
+    var_names = _var_names(var_names, coords_data, filter_vars)
 
     if compact:
-        skip_dims = set(data.dims) - {"chain", "draw"}
+        skip_dims = set(coords_data.dims) - {"chain", "draw"}
     else:
         skip_dims = set()
 
-    plotters = list(xarray_var_iter(data, var_names=var_names, combined=True, skip_dims=skip_dims))
+    plotters = list(
+        xarray_var_iter(coords_data, var_names=var_names, combined=True, skip_dims=skip_dims)
+    )
     max_plots = rcParams["plot.max_subplots"]
     max_plots = len(plotters) if max_plots is None else max(max_plots // 2, 1)
     if len(plotters) > max_plots:
@@ -199,7 +205,7 @@ def plot_trace(
     # TODO: Check if this can be further simplified
     trace_plot_args = dict(
         # User Kwargs
-        data=data,
+        data=coords_data,
         var_names=var_names,
         # coords = coords,
         divergences=divergences,
