@@ -501,12 +501,12 @@ def test_plot_kde_inference_data(models):
             "divergences": True,
             "coords": {"theta_dim_0": [0, 1]},
             "scatter_kwargs": {"marker": "x"},
-            "divergences_kwargs": {"marker": "*", "c": "C"},
+            "divergences_kwargs": {"marker": "*", "c": "C0"},
         },
         {
             "divergences": True,
             "scatter_kwargs": {"marker": "x"},
-            "divergences_kwargs": {"marker": "*", "c": "C"},
+            "divergences_kwargs": {"marker": "*", "c": "C0"},
             "var_names": ["theta", "mu"],
         },
         {"kind": "kde", "var_names": ["theta"]},
@@ -523,7 +523,7 @@ def test_plot_kde_inference_data(models):
         {
             "point_estimate": "mean",
             "reference_values": {"mu": 0, "tau": 0},
-            "reference_values_kwargs": {"c": "C", "marker": "*"},
+            "reference_values_kwargs": {"c": "C0", "marker": "*"},
         },
     ],
 )
@@ -794,6 +794,14 @@ def test_plot_ppc_bad_ax(models, fig_ax):
         plot_ppc(models.model_1, ax=ax2)
 
 
+def test_plot_legend(models):
+    axes = plot_ppc(models.model_1)
+    legend_texts = axes.get_legend().get_texts()
+    result = [i.get_text() for i in legend_texts]
+    expected = ["Posterior predictive", "Observed", "Posterior predictive mean"]
+    assert result == expected
+
+
 @pytest.mark.parametrize("var_names", (None, "mu", ["mu", "tau"]))
 def test_plot_violin(models, var_names):
     axes = plot_violin(models.model_1, var_names=var_names)
@@ -1286,11 +1294,11 @@ def test_plot_ess_no_divergences(models):
         {},
         {"n_unif": 50, "legend": False},
         {"use_hdi": True, "color": "gray"},
-        {"use_hdi": True, "credible_interval": 0.68},
+        {"use_hdi": True, "hdi_prob": 0.68},
         {"use_hdi": True, "hdi_kwargs": {"fill": 0.1}},
         {"ecdf": True},
         {"ecdf": True, "ecdf_fill": False, "plot_unif_kwargs": {"ls": "--"}},
-        {"ecdf": True, "credible_interval": 0.97, "fill_kwargs": {"hatch": "/"}},
+        {"ecdf": True, "hdi_prob": 0.97, "fill_kwargs": {"hatch": "/"}},
     ],
 )
 def test_plot_loo_pit(models, kwargs):
